@@ -1,19 +1,7 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2009 Dario Freddi <drf at kde.org>
+   SPDX-FileCopyrightText: 2009 Dario Freddi <drf at kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 // Exceptionnally, include QCoreApplication before our own header, because that one includes X11 headers (#define None...)
@@ -31,12 +19,20 @@
 class XSyncBasedPollerHelper : public QAbstractNativeEventFilter
 {
 public:
-    XSyncBasedPollerHelper() : q(nullptr), isActive(false) {}
+    XSyncBasedPollerHelper()
+        : q(nullptr)
+        , isActive(false)
+    {
+    }
     ~XSyncBasedPollerHelper()
     {
         delete q;
     }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override
+#else
     bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override
+#endif
     {
         Q_UNUSED(result);
         if (isActive && eventType == "xcb_generic_event_t") {
@@ -90,7 +86,7 @@ XSyncBasedPoller::XSyncBasedPoller(QObject *parent)
 #if 0
 
     // Workaround for https://bugs.freedesktop.org/show_bug.cgi?id=23403
-#define xcb_sync_systemcounter_name(sc) (((char *) &(sc)->name_len) + 2)
+#define xcb_sync_systemcounter_name(sc) (((char *)&(sc)->name_len) + 2)
 
     xcb_sync_list_system_counters_cookie_t cookie = xcb_sync_list_system_counters(m_xcb_connection);
     xcb_sync_list_system_counters_reply_t *reply = xcb_sync_list_system_counters_reply(m_xcb_connection, cookie, NULL);
@@ -202,8 +198,7 @@ void XSyncBasedPoller::addTimeout(int nextTimeout)
 
     XSyncIntToValue(&timeout, nextTimeout);
 
-    setAlarm(m_display, &newalarm, m_idleCounter,
-             XSyncPositiveComparison, timeout);
+    setAlarm(m_display, &newalarm, m_idleCounter, XSyncPositiveComparison, timeout);
 
     m_timeoutAlarm.insert(nextTimeout, newalarm);
 }
@@ -254,14 +249,13 @@ void XSyncBasedPoller::catchIdleEvent()
      * we have to subtract 1 from the counter value
      */
 
-    //NOTE: this must be a int, else compilation might fail
+    // NOTE: this must be a int, else compilation might fail
     int overflow;
     XSyncValue add;
     XSyncValue plusone;
     XSyncIntToValue(&add, -1);
     XSyncValueAdd(&plusone, idleTime, add, &overflow);
-    setAlarm(m_display, &m_resetAlarm, m_idleCounter,
-             XSyncNegativeComparison, plusone);
+    setAlarm(m_display, &m_resetAlarm, m_idleCounter, XSyncNegativeComparison, plusone);
 }
 
 void XSyncBasedPoller::reloadAlarms()
@@ -271,8 +265,7 @@ void XSyncBasedPoller::reloadAlarms()
     for (QHash<int, XSyncAlarm>::iterator i = m_timeoutAlarm.begin(); i != m_timeoutAlarm.end(); ++i) {
         XSyncIntToValue(&timeout, i.key());
 
-        setAlarm(m_display, &(i.value()), m_idleCounter,
-                 XSyncPositiveComparison, timeout);
+        setAlarm(m_display, &(i.value()), m_idleCounter, XSyncPositiveComparison, timeout);
     }
 }
 
@@ -292,7 +285,7 @@ bool XSyncBasedPoller::xcbEvent(xcb_generic_event_t *event)
     for (QHash<int, XSyncAlarm>::const_iterator i = m_timeoutAlarm.constBegin(); i != m_timeoutAlarm.constEnd(); ++i) {
         if (alarmEvent->alarm == i.value()) {
             /* Bling! Caught! */
-            emit timeoutReached(i.key());
+            Q_EMIT timeoutReached(i.key());
             // Update the alarm to fire back if the system gets inactive for the same time
             catchIdleEvent();
             return false;
@@ -303,32 +296,30 @@ bool XSyncBasedPoller::xcbEvent(xcb_generic_event_t *event)
         /* Resuming from idle here! */
         stopCatchingIdleEvents();
         reloadAlarms();
-        emit resumingFromIdle();
+        Q_EMIT resumingFromIdle();
     }
 
     return false;
 }
 
-void XSyncBasedPoller::setAlarm(Display *dpy, XSyncAlarm *alarm, XSyncCounter counter,
-                                XSyncTestType test, XSyncValue value)
+void XSyncBasedPoller::setAlarm(Display *dpy, XSyncAlarm *alarm, XSyncCounter counter, XSyncTestType test, XSyncValue value)
 {
-    XSyncAlarmAttributes  attr;
-    XSyncValue            delta;
-    unsigned int          flags;
+    XSyncAlarmAttributes attr;
+    XSyncValue delta;
+    unsigned int flags;
 
     XSyncIntToValue(&delta, 0);
 
-    attr.trigger.counter     = counter;
-    attr.trigger.value_type  = XSyncAbsolute;
-    attr.trigger.test_type   = test;
-    attr.trigger.wait_value  = value;
-    attr.delta               = delta;
+    attr.trigger.counter = counter;
+    attr.trigger.value_type = XSyncAbsolute;
+    attr.trigger.test_type = test;
+    attr.trigger.wait_value = value;
+    attr.delta = delta;
 
-    flags = XSyncCACounter | XSyncCAValueType | XSyncCATestType |
-            XSyncCAValue | XSyncCADelta;
+    flags = XSyncCACounter | XSyncCAValueType | XSyncCATestType | XSyncCAValue | XSyncCADelta;
 
     if (*alarm) {
-        //xcb_sync_change_alarm_checked(m_xcb_connection, alarmId,  ...
+        // xcb_sync_change_alarm_checked(m_xcb_connection, alarmId,  ...
         XSyncChangeAlarm(dpy, *alarm, flags, &attr);
     } else {
         *alarm = XSyncCreateAlarm(dpy, flags, &attr);
@@ -343,4 +334,3 @@ void XSyncBasedPoller::simulateUserActivity()
     XResetScreenSaver(m_display);
     XFlush(m_display);
 }
-
